@@ -156,6 +156,12 @@ data = {
                         "action": "store_true",
                         "help": "Tell the command to automatically stage files that have been modified and deleted, but new files you have not told Git about are not affected.",
                     },
+                    {
+                        "name": ["-e", "--edit"],
+                        "action": "store_true",
+                        "default": False,
+                        "help": "edit the commit message before committing",
+                    },
                     {
                         "name": ["-l", "--message-length-limit"],
                         "type": int,
@@ -353,6 +359,12 @@ data = {
                         "help": "Add additional build-metadata to the version-number",
                         "default": None,
                     },
+                    {
+                        "name": ["--get-next"],
+                        "action": "store_true",
+                        "help": "Determine the next version and write to stdout",
+                        "default": False,
+                    },
                 ],
             },
             {
@@ -466,6 +478,12 @@ data = {
                         "If the message starts by one of these prefixes, "
                         "the message won't be checked against the regex",
                     },
+                    {
+                        "name": ["-l", "--message-length-limit"],
+                        "type": int,
+                        "default": 0,
+                        "help": "length limit of the commit message; 0 for no limit",
+                    },
                 ],
             },
             {
